// All database related API calls

import { BackendQueryFormat } from '../../querybuilder';
import { Broker } from './broker';
import { QueryBuilderText } from '../store/querybuilderSlice';
import { GraphQueryResultFromBackendPayload } from '../store/graphQueryResultSlice';

export function wsQueryRequest(query: BackendQueryFormat) {
  if (query.cached === undefined) query.cached = false;
  Broker.instance().sendMessage({
    key: 'query',
    subKey: 'get',
    body: query,
  });
}

export function wsManualQueryRequest(query: string) {
  Broker.instance().sendMessage({
    key: 'query',
    subKey: 'manual',
    body: JSON.stringify({ query }),
  });
}

type QueryTranslationResponse = (data: QueryBuilderText) => void;
export function wsQueryTranslationSubscription(callback: QueryTranslationResponse) {
  const id = Broker.instance().subscribe(callback, 'queryTranslation_result');
  return () => {
    Broker.instance().unSubscribe('queryTranslation_result', id);
  };
}

type QueryResultResponse = (data: GraphQueryResultFromBackendPayload) => void;
export function wsQuerySubscription(callback: QueryResultResponse) {
  const id = Broker.instance().subscribe(callback, 'query_result');
  return () => {
    Broker.instance().unSubscribe('query_result', id);
  };
}
