import { CytoscapeLayout, CytoscapeLayoutAlgorithms, CytoscapeLayouts, CytoscapeProvider } from './cytoscape-layouts';
import { GraphologyLayout, GraphologyLayoutAlgorithms, GraphologyLayouts, GraphologyProvider } from './graphology-layouts';
import { ListLayout, ListLayoutAlgorithms, ListLayoutProvider, ListLayouts } from './list-layouts';

export type AllLayoutAlgorithms = GraphologyLayoutAlgorithms | CytoscapeLayoutAlgorithms | ListLayoutAlgorithms;

export type Providers = GraphologyProvider | CytoscapeProvider | ListLayoutProvider;
export type LayoutAlgorithm<Provider extends Providers> = `${Provider}_${string}`;

export type AlgorithmToLayoutProvider<Algorithm extends AllLayoutAlgorithms = AllLayoutAlgorithms> =
  Algorithm extends GraphologyLayoutAlgorithms
    ? GraphologyLayout
    : Algorithm extends CytoscapeLayoutAlgorithms
      ? CytoscapeLayout
      : ListLayout;

export const Layouts = {
  ...GraphologyLayouts,
  ...CytoscapeLayouts,
  ...ListLayouts,
} as const;

export type LayoutTypes = (typeof Layouts)[keyof typeof Layouts];
