import { configureStore } from '@reduxjs/toolkit';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { mockLargeQueryResults } from '../../../mock-data/query-result';
import ArcPlotComponent from './arcplotvis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof ArcPlotComponent.component> = {
  title: 'Visualizations/ArcPlotVis',
  component: ArcPlotComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const SimpleData = {
  args: {
    data: {
      nodes: [
        { _id: 'agent/007', attributes: { name: 'Daniel Craig' } },
        { _id: 'villain', attributes: { name: 'Le Chiffre' } },
      ],
      edges: [
        {
          attributes: {
            Type: 'PERSUES',
          },
          from: 'agent/007',
          _id: '14514',
          to: 'villain',
        },
      ],
    },
    configuration: ArcPlotComponent.configuration,
  },
};

export const LargeData = {
  args: {
    data: mockLargeQueryResults,
    configuration: ArcPlotComponent.configuration,
  },
};

export const Empty = {
  args: {
    data: {
      nodes: [],
      edges: [],
    },
    configuration: ArcPlotComponent.configuration,
  },
};

export default Component;
